from agentmake import agentmake
from agentmake.utils.online import get_local_ip
from agentmake.plugins.uba.lib.BibleParser import BibleVerseParser
from biblemate import config, AGENTMAKE_CONFIG
from urllib.parse import quote
import requests, os, re, traceback

DEFAULT_MODULES = {
    "bible": config.default_bible,
    "chapter": config.default_bible,
    "xref": config.default_bible,
    "treasury": config.default_bible,
    "search": config.default_bible,
    "genesis": config.default_bible,
    "exodus": config.default_bible,
    "leviticus": config.default_bible,
    "numbers": config.default_bible,
    "deuteronomy": config.default_bible,
    "joshua": config.default_bible,
    "judges": config.default_bible,
    "ruth": config.default_bible,
    "samuel1": config.default_bible,
    "samuel2": config.default_bible,
    "kings1": config.default_bible,
    "kings2": config.default_bible,
    "chronicles1": config.default_bible,
    "chronicles2": config.default_bible,
    "ezra": config.default_bible,
    "nehemiah": config.default_bible,
    "esther": config.default_bible,
    "job": config.default_bible,
    "psalms": config.default_bible,
    "proverbs": config.default_bible,
    "ecclesiastes": config.default_bible,
    "songs": config.default_bible,
    "isaiah": config.default_bible,
    "jeremiah": config.default_bible,
    "lamentations": config.default_bible,
    "ezekiel": config.default_bible,
    "daniel": config.default_bible,
    "hosea": config.default_bible,
    "joel": config.default_bible,
    "amos": config.default_bible,
    "obadiah": config.default_bible,
    "jonah": config.default_bible,
    "micah": config.default_bible,
    "nahum": config.default_bible,
    "habakkuk": config.default_bible,
    "zephaniah": config.default_bible,
    "haggai": config.default_bible,
    "zechariah": config.default_bible,
    "malachi": config.default_bible,
    "matthew": config.default_bible,
    "mark": config.default_bible,
    "luke": config.default_bible,
    "john": config.default_bible,
    "acts": config.default_bible,
    "romans": config.default_bible,
    "corinthians1": config.default_bible,
    "corinthians2": config.default_bible,
    "galatians": config.default_bible,
    "ephesians": config.default_bible,
    "philippians": config.default_bible,
    "colossians": config.default_bible,
    "thessalonians1": config.default_bible,
    "thessalonians2": config.default_bible,
    "timothy1": config.default_bible,
    "timothy2": config.default_bible,
    "titus": config.default_bible,
    "philemon": config.default_bible,
    "hebrews": config.default_bible,
    "james": config.default_bible,
    "peter1": config.default_bible,
    "peter2": config.default_bible,
    "john1": config.default_bible,
    "john2": config.default_bible,
    "john3": config.default_bible,
    "jude": config.default_bible,
    "revelation": config.default_bible,
    "parallel": config.default_bible,
    "promise": config.default_bible,
    "commentary": config.default_commentary,
    "encyclopedia": config.default_encyclopedia,
    "lexicon": config.default_lexicon,
}

# api
def run_bm_api(query: str, language: str="eng") -> str:
    # 1. Define the URL
    url = os.getenv("BM_API_ENDPOINT", "https://biblemate.gospelchurch.uk/api/data")
    # 2. Define your parameters
    payload = {
        "query": quote(query),
        "language": language, # Optional
        "token": os.getenv("BM_API_CUSTOM_KEY", "") # Optional
    }
    # 3. Send the GET request
    try:
        response = requests.get(url, params=payload, timeout=int(os.getenv("BM_API_TIMEOUT", 10)))
        # 4. Check if the request was successful (Status Code 200)
        if response.status_code == 200:
            data = response.json()  # Convert JSON response to Python dict
            api_content = data.get("content", "[NO_CONTENT]")
            if api_content == "\n\n":
                api_content = "[NO_CONTENT]"
            return api_content
        else:
            print(f"Error: {response.status_code}")
            return response.text
    except requests.exceptions.ConnectionError:
        print("Could not connect to BibleMate AI API server.")
    except Exception as err:
        traceback.print_exc()
        return f"An error occurred: {err}"



import os, re
from biblemate import config
from agentmake import PACKAGE_PATH, AGENTMAKE_USER_DIR, readTextFile
from pathlib import Path

# set up user_directory for customisation
user_directory = os.path.join(AGENTMAKE_USER_DIR, "biblemate")
Path(user_directory).mkdir(parents=True, exist_ok=True)

def get_system_progress(master_plan: str) -> str:
    """
    create system prompt for checking the progress
    """
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "biblemate", "supervisor.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "biblemate", "supervisor.md")
    system_progress = readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1).format(master_plan=master_plan)
    if not "Preliminary Action Plan" in master_plan: # custom mcp prompts
        system_progress = system_progress.replace("\n# Master Plan", "\n# Preliminary Action Plan")
    return system_progress

def get_system_make_suggestion(master_plan: str) -> str:
    """
    create system prompt for makding suggestion
    """
    action_plan = re.sub("[# ]*?Measurable Outcome.*?$", "", master_plan, flags=re.DOTALL)
    action_plan = re.sub("[# ]*?Preliminary Action Plan", "", action_plan)
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "biblemate", "make_suggestions.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "biblemate", "make_suggestions.md")
    return readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1).format(action_plan=action_plan)

def get_system_tool_instruction(tool: str, tool_description: str = "") -> str:
    """
    create system prompt for tool instruction
    """
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "biblemate", "tool_instruction.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "biblemate", "tool_instruction.md")
    return readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1).format(tool=tool, tool_description=tool_description)

def get_system_tool_selection(available_tools: list, tool_descriptions: str) -> str:
    """
    create system prompt for tool selection
    """
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "biblemate", "tool_selection_lite.md" if config.light else "tool_selection.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "biblemate", "tool_selection_lite.md" if config.light else "tool_selection.md")
    return readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1).format(available_tools=available_tools, tool_descriptions=tool_descriptions)

def get_system_master_plan() -> str:
    """
    create system prompt for master plan generation
    """
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "create_action_plan.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "create_action_plan.md")
    system_content = readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1)
    return system_content+"""\n
-  Avoid specifying particular Bible versions (e.g., KJV, NIV) or copyrighted materials unless explicitly supported by the tool's documentation. When retrieving Bible verses or materials is required, simply prompt the tools to retrieve them and defer version selection to the tool's native configuration. To maintain a seamless experience, do not solicit version preferences from the user."""

def get_system_improve_prompt_2() -> str:
    """
    create system prompt for prompt engineering
    """
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "improve_prompt_2.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "improve_prompt_2.md")
    return readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1)

def get_system_generate_title() -> str:
    """
    create system prompt for title generation
    """
    possible_system_file_path_2 = os.path.join(PACKAGE_PATH, "systems", "generate_title.md")
    possible_system_file_path_1 = os.path.join(AGENTMAKE_USER_DIR, "systems", "generate_title.md")
    system_prompt = readTextFile(possible_system_file_path_2 if os.path.isfile(possible_system_file_path_2) else possible_system_file_path_1)
    return system_prompt


import os
from biblemate import BIBLEMATE_PACKAGE_DIR
from pathlib import Path
import argparse
import shutil

parser = argparse.ArgumentParser(description = f"""Install/Update BibleMate AI MCP SKILLs CLI options""")
parser.add_argument("-a", "--antigravity", action="store_true", dest="antigravity", help="Install/Update Antigravity skill.")
parser.add_argument("-c", "--claude", action="store_true", dest="claude", help="Install/Update Claude Code skill.")
parser.add_argument("-g", "--gemini", action="store_true", dest="gemini", help="Install/Update Gemini CLI skill.")
parser.add_argument("-o", "--openclaw", action="store_true", dest="openclaw", help="Install/Update OpenClaw skill.")
args = parser.parse_args()

def install_skill():
    print("Installing BibleMate skill...")
    if args.antigravity:
        print("Installing Antigravity skill...")
        antigravity_skill_dir = os.path.expanduser("~/.gemini/antigravity/skills/bible-study")
        if not os.path.isdir(antigravity_skill_dir):
            Path(antigravity_skill_dir).mkdir(parents=True, exist_ok=True)
        shutil.copy(os.path.join(BIBLEMATE_PACKAGE_DIR, "skills", "antigravity", "SKILL.md"), antigravity_skill_dir)
    if args.claude:
        print("Installing Claude Code skill...")
        claude_skill_dir = os.path.expanduser("~/.claude/skills/bible-study")
        if not os.path.isdir(claude_skill_dir):
            Path(claude_skill_dir).mkdir(parents=True, exist_ok=True)
        shutil.copy(os.path.join(BIBLEMATE_PACKAGE_DIR, "skills", "antigravity", "SKILL.md"), claude_skill_dir)
    if args.gemini:
        print("Installing Gemini CLI skill...")
        gemini_skill_dir = os.path.expanduser("~/.gemini/skills/bible-study")
        if not os.path.isdir(gemini_skill_dir):
            Path(gemini_skill_dir).mkdir(parents=True, exist_ok=True)
        shutil.copy(os.path.join(BIBLEMATE_PACKAGE_DIR, "skills", "antigravity", "SKILL.md"), gemini_skill_dir)
    if args.openclaw:
        print("Installing OpenClaw skill...")
        openclaw_skill_dir = os.path.expanduser("~/.openclaw/skills/bible-study")
        if not os.path.isdir(openclaw_skill_dir):
            Path(openclaw_skill_dir).mkdir(parents=True, exist_ok=True)
        shutil.copy(os.path.join(BIBLEMATE_PACKAGE_DIR, "skills", "openclaw", "SKILL.md"), openclaw_skill_dir)

if __name__ == "__main__":
    install_skill()
    